import { RouteConfig } from "#/route";

export const AccountManager: RouteConfig = {
  name: "AccountManager",
  path: "/account",
  icon: "ProjectOutlined",
  meta: {
    title: "公众号管理"
  },
  component: () => import("@/views/account/account.vue")
};

const PutBook: RouteConfig = {
  name: "PutBook",
  path: "book",
  meta: {
    title: "投放书籍"
  },
  component: () => import("@/views/put/put-book.vue")
};

const PutAdAccount: RouteConfig = {
  name: "PutAdAccount",
  path: "ad-account",
  meta: {
    title: "广告账号"
  },
  component: () => import("@/views/put/put-ad-account.vue")
};

const PutData: RouteConfig = {
  name: "PutData",
  path: "data",
  meta: {
    title: "投放数据"
  },
  component: () => import("@/views/put/put-data.vue")
};

const LandingPage: RouteConfig = {
  name: "LandingPage",
  path: "landing",
  meta: {
    title: "落地页管理"
  },
  component: () => import("@/views/put/landing/index.vue")
};

const LandingAddPage: RouteConfig = {
  name: "LandingAddPage",
  path: "/put/landing/add",
  meta: {
    title: "落地页添加",
    activeMenu: "/put/landing"
  },
  hidden: true,
  component: () => import("@/views/put/landing/add.vue")
};
export const LandingEditPage: RouteConfig = {
  name: "LandingEditPage",
  path: "/put/landing/edit",
  meta: {
    title: "落地页编辑",
  },
  component: () => import("@/views/put/landing/edit.vue"),
};
const PutLog: RouteConfig = {
  name: "PutLog",
  path: "log",
  meta: {
    title: "操作日志"
  },
  component: () => import("@/views/put/put-log.vue")
};

const PutDataMore: RouteConfig = {
  name: "PutDataMore",
  path: "datamore",
  meta: {
    title: "更多投放数据",
    activeMenu: "/put/data"
  },
  hidden: true,
  component: () => import("@/views/put/put-data-more.vue")
};

const PutAdGroup: RouteConfig = {
  name: "PutAdGroup",
  path: "/put/datas/group",
  meta: {
    title: "广告组数据",
    activeMenu: "/put/datas"
  },
  component: () => import("@/views/put/ad-group.vue")
};

const PutAdAcountL: RouteConfig = {
  name: "PutAdAcountL",
  path: "/put/datas/count",
  meta: {
    title: "广告账号数据",
    activeMenu: "/put/datas"
  },
  component: () => import("@/views/put/ad-countdata.vue")
};

const PutAdPlan: RouteConfig = {
  name: "PutAdPlan",
  path: "/put/datas/ad-plan",
  meta: {
    title: "广告计划数据",
    activeMenu: "/put/datas"
  },
  component: () => import("@/views/put/put-ad-plan.vue")
};

export const PutDataTab: RouteConfig = {
  name: "PutDataTab",
  path: "/put/datas",
  meta: {
    title: "广告数据",
    noMenu: true
  },
  children: [PutAdAcountL, PutAdGroup, PutAdPlan],
  component: () => import("@/views/put/ad_datas.vue")
};

export const PutManager: RouteConfig = {
  name: "PutManager",
  path: "/put",
  icon: "DesktopOutlined",
  meta: {
    title: "投放管理"
  },
  children: [
    PutBook,
    PutAdAccount,
    PutDataTab,
    PutData,
    PutDataMore,
    LandingPage,
    LandingAddPage
  ],
  component: () => import("@/views/put/index.vue")
};

export const Financial: RouteConfig = {
  name: "Financial",
  path: "/financial",
  icon: "PayCircleOutlined",
  meta: {
    title: "财务管理"
  },
  component: () => import("@/views/financial/index.vue")
};

export const QuickApp: RouteConfig = {
  name: "QuickApp",
  path: "/quickapp",
  icon: "ProjectOutlined",
  meta: {
    title: "阅文快应用"
  },
  component: () => import("@/views/read/quick-app.vue")
};

export const Performance: RouteConfig = {
  name: "Performance",
  path: "/data/performance",
  meta: {
    title: "员工绩效",
    noMenu: true
  },
  // children: [PutAdAcountL, PutAdGroup, PutAdPlan],
  component: () => import("@/views/data/performance.vue")
};

export const DataAnalysis: RouteConfig = {
  name: "DataAnalysis",
  path: "/data",
  icon: "DesktopOutlined",
  meta: {
    title: "数据分析"
  },
  children: [
    Performance,
  ],
  component: () => import("@/views/data/index.vue")
};

export const ForgetPwd: RouteConfig = {
  name: "ForgetPwd",
  path: "/forgetpwd",
  hidden: true,
  meta: {
    title: "忘记密码",
  },
  component: () => import("@/views/Password.vue"),
};



const asyncRoutes: RouteConfig[] = [AccountManager, PutManager, Financial, QuickApp, ForgetPwd, DataAnalysis];

export default asyncRoutes;
